pub(crate) struct Acquire<'a> {
node: Waiter,
semaphore: &'a Semaphore,
num_permits: usize,
queued: bool,
}Fields
node: Waitersemaphore: &'a Semaphorenum_permits: usizequeued: boolWhether Acquire::drop must clean up after the waiter, by removing it
from the wait queue if it is still linked and returning the permits
assigned to it to the semaphore.
This is set as soon as poll_acquire assigns permits to the waiter or
links it into the wait queue, and it is only cleared once the future
completes and the permits are handed to the caller.
Implementations